==> xslt-generator-maven-plugin-1.4-sources.jar: net/sf/xsltmp/SrcDirURIResolver.java <==
package net.sf.xsltmp;

import java.io.File;

import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;

import net.sf.xsltmp.util.DefaultURIResolver;
import net.sf.xsltmp.util.UnArchiverHelper;

import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;

/**
 * URIResolver that resolves either from source directory, the received base
 * URI, as an absolute path, from project basedir or from classpath.
 * <p>
 * First tries to resolve from the source directory.
 * <p>
 * Then resolves from the other options, see
 * {@link DefaultURIResolver} for details.
 */
public class SrcDirURIResolver extends DefaultURIResolver {

	/**
	 * The source dir
	 */
	private final File srcDir;

	/**
	 * Constructor.
	 * 
	 * @param srcDir
	 *            The source dir
	 * @param log
	 *            Maven log
	 * @param project
	 *            Maven project
	 * @param helper
	 *            UnArchiver helper
	 */
	public SrcDirURIResolver(File srcDir, Log log, MavenProject project,
			UnArchiverHelper helper) {
		super(log, project, helper);
		this.srcDir = srcDir;
	}

	public File getSrcDir() {
		return srcDir;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sf.seaf.mojo.util.BasedirAndClasspathURIResolver#resolve(java.lang
	 * .String, java.lang.String)
	 */
	public Source resolve(String href, String base) {
		getLog().debug("Resolving: " + href + " at srcDir: " + getSrcDir());
		File result = new File(getSrcDir(), href);
		if (exists(result))
			return new StreamSource(result);
		return super.resolve(href, base);
	}

}

==> xslt-generator-maven-plugin-1.5-sources.jar: net/sf/xsltmp/SrcDirURIResolver.java <==
package net.sf.xsltmp;

import java.io.File;
import java.util.Map;

import javax.xml.transform.Source;
import javax.xml.transform.TransformerConfigurationException;

import net.sf.xsltmp.util.DefaultURIResolver;
import net.sf.xsltmp.util.UnArchiverHelper;

import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;

/**
 * URIResolver that resolves either from source directory, the received base
 * URI, as an absolute path, from project basedir or from classpath.
 * <p>
 * First tries to resolve from the source directory.
 * <p>
 * Then resolves from the other options, see {@link DefaultURIResolver} for
 * details.
 */
public class SrcDirURIResolver extends DefaultURIResolver {

	/**
	 * The source dir
	 */
	private final File srcDir;

	/**
	 * Constructor.
	 * 
	 * @param srcDir
	 *            The source dir
	 * @param log
	 *            Maven log
	 * @param project
	 *            Maven project
	 * @param helper
	 *            UnArchiver helper
	 */
	public SrcDirURIResolver(File srcDir, Log log, MavenProject project,
			UnArchiverHelper helper, String filter, Map filterParameters) {
		super(log, project, helper, filter, filterParameters);
		this.srcDir = srcDir;
	}

	public File getSrcDir() {
		return srcDir;
	}

	public Source resolve(String href, String base)
			throws TransformerConfigurationException {
		if (getLog().isDebugEnabled())
			getLog().debug("Resolving: " + href + " at srcDir: " + getSrcDir());
		File result = new File(getSrcDir(), href);
		if (exists(result))
			return createSource(result);
		return super.resolve(href, base);
	}

}
